@@ -7,7 +7,7 @@ use 5.008;
 
 use vars qw($VERSION);
 
-$VERSION = '0.3.2';
+$VERSION = '0.3.3';
 
 package HTML::Latemp::GenMakeHelpers::Base;
 
@@ -434,7 +434,7 @@ HTML::Latemp::GenMakeHelpers - A Latemp Utility Module.
 
 =head1 VERSION
 
-version 0.3.2
+version 0.3.3
 
 =head1 SYNOPSIS
 
@@ -495,7 +495,7 @@ Process the host $host.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
@@ -575,7 +575,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Latemp-GenMakeHelpers>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Latemp-GenMakeHelpers>
 
 =item *
 
@@ -607,7 +607,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/HTML-Latemp-GenMakeHelpers>
+L<http://cpants.cpanauthors.org/dist/HTML-Latemp-GenMakeHelpers>
 
 =item *
 
@@ -638,7 +638,7 @@ L<http://deps.cpantesters.org/?module=HTML::Latemp::GenMakeHelpers>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-html-latemp-genmakehelpers at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-GenMakeHelpers>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=HTML-Latemp-GenMakeHelpers>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
